 * Ensure that the application source handles exceptions and errors in
a such a way that no sensitive information is disclosed to the users

* Configure the application server to handle and log any exceptions
that the application might yield
